pub struct CodegenConfig {
    pub models: Vec<ModelSource>,
    pub output_languages: Vec<OutputLanguage>,
    pub languages: BTreeMap<OutputLanguage, LanguageConfig>,
    pub base_dir: PathBuf,
}

Fields

models: Vec<ModelSource>

model inputs

output_languages: Vec<OutputLanguage>

This can be set by the cli to limit the languages generated. Without this flag, all languages in the toml file are generated.

languages: BTreeMap<OutputLanguage, LanguageConfig>

Language-specific output configuration

base_dir: PathBuf

The directory containing the codegen.toml file, and the base_dir used for evaluating all relative paths in the file. This is not set inside the toml file but is set by the file reader, It is always set to an absolute path