pub struct OutputFile {
    pub path: PathBuf,
    pub hbs: Option<String>,
    pub create_only: bool,
    pub namespace: Option<String>,
    pub params: BTreeMap<String, TomlValue>,
}
Output-file specific settings

Fields

path: PathBuf

path to output file, relative to language output_dir. Required.

hbs: Option<String>

name of handlebars template file (without hbs extension) Not used for files generated by codegen

create_only: bool

True if file should be generated only for ‘create’ operations

namespace: Option<String>

Optionally, limit code generation for this file to shapes in this namespace

params: BTreeMap<String, TomlValue>

optional additional parameters for this file