Function weld_codegen::templates_from_dir
source · Expand description
Add all templates from the specified folder, using the base file name as the template name. For example, “header.hbs” will be registered as “header”
Add all templates from the specified folder, using the base file name as the template name. For example, “header.hbs” will be registered as “header”